package com.op.wms.mapper;

import java.util.List;

import com.op.wms.domain.BaseProductGroupsT;

/**
 * 物料分组Mapper接口
 * 
 * @author Open Platform
 * @date 2023-07-18
 */
public interface BaseProductGroupsTMapper {
	/**
	 * 查询物料分组
	 * 
	 * @param pgId 物料分组主键
	 * @return 物料分组
	 */
	public BaseProductGroupsT selectBaseProductGroupsTByPgId(String pgId);

	/**
	 * 查询物料分组列表
	 * 
	 * @param baseProductGroupsT 物料分组
	 * @return 物料分组集合
	 */
	public List<BaseProductGroupsT> selectBaseProductGroupsTList(BaseProductGroupsT baseProductGroupsT);

	/**
	 * 新增物料分组
	 * 
	 * @param baseProductGroupsT 物料分组
	 * @return 结果
	 */
	public int insertBaseProductGroupsT(BaseProductGroupsT baseProductGroupsT);

	/**
	 * 修改物料分组
	 * 
	 * @param baseProductGroupsT 物料分组
	 * @return 结果
	 */
	public int updateBaseProductGroupsT(BaseProductGroupsT baseProductGroupsT);

	/**
	 * 删除物料分组
	 * 
	 * @param pgId 物料分组主键
	 * @return 结果
	 */
	public int deleteBaseProductGroupsTByPgId(String pgId);

	/**
	 * 批量删除物料分组
	 * 
	 * @param pgIds 需要删除的数据主键集合
	 * @return 结果
	 */
	public int deleteBaseProductGroupsTByPgIds(String[] pgIds);
}
